@@ -117,7 +117,9 @@ Calendar={
 			//24 * 60 * 60 = 86400, # of seconds in a day
 			var topLoc = Math.floor(parentDiv.height() * percentOfDay);
 			var appNavigationWidth = ($(window).width() > 768) ? $('#app-navigation').width() : 0;
-			timeline.css({'left':($('.fc-today').offset().left-appNavigationWidth),'width': $('.fc-today').width(),'top':topLoc + 'px'});
+			if (timeline.is(':visible')) {
+				timeline.css({'left':($('.fc-today').offset().left-appNavigationWidth),'width': $('.fc-today').width(),'top':topLoc + 'px'});
+			}
 		},
 	},
 	UI:{
@@ -728,10 +730,10 @@ Calendar={
 						var permissions = OC.PERMISSION_READ | OC.PERMISSION_SHARE;
 						OC.Share.share(itemType, itemSource, shareType, shareWith, permissions, function(data) {
 							var newitem = '<li data-item-type="event"'
-								+ 'data-share-with="'+shareWith+'" '
-								+ 'data-permissions="'+permissions+'" '
-								+ 'data-share-type="'+shareType+'">'
-								+ shareWith
+								+ 'data-share-with="'+escapeHTML(shareWith)+'" '
+								+ 'data-permissions="'+escapeHTML(permissions)+'" '
+								+ 'data-share-type="'+escapeHTML(shareType)+'">'
+								+ escapeHTML(shareWith)
 								+ (shareType === OC.Share.SHARE_TYPE_GROUP ? ' ('+t('core', 'group')+')' : '')
 								+ '<span class="shareactions">'
 								+ '<label><input class="update" type="checkbox" checked="checked">'+t('core', 'can edit')+'</label>'
