@@ -27,7 +27,9 @@ $success = true;
 //Now delete
 foreach ($files as $file) {
 	if (\OC\Files\Filesystem::file_exists($dir . '/' . $file) &&
-			!\OC\Files\Filesystem::unlink($dir . '/' . $file)) {
+		!(\OC\Files\Filesystem::isDeletable($dir . '/' . $file) &&
+			\OC\Files\Filesystem::unlink($dir . '/' . $file))
+	) {
 		$filesWithError .= $file . "\n";
 		$success = false;
 	}
