@@ -23,6 +23,7 @@
  */
 
 namespace OCA\Encryption;
+use OC\User\NoUserException;
 
 /**
  * Class for utilities relating to encrypted file storage system
@@ -903,8 +904,14 @@ class Util {
 		) {
 			return true;
 		}
-		$util = new Util($this->view, $user);
-		return $util->ready();
+		try {
+			$util = new Util($this->view, $user);
+			return $util->ready();
+		} catch (NoUserException $e) {
+			\OCP\Util::writeLog('Encryption library',
+				'No User object for '.$user, \OCP\Util::DEBUG);
+			return false;
+		}
 	}
 
 	/**
