@@ -462,6 +462,8 @@ describe('Core base tests', function() {
 			it('renders file sizes with the correct unit', function() {
 				var data = [
 					[0, '0 B'],
+					["0", '0 B'],
+					["A", 'NaN B'],
 					[125, '125 B'],
 					[128000, '125 kB'],
 					[128000000, '122.1 MB'],
