@@ -71,7 +71,6 @@ class OC_App {
 		ob_start();
 		foreach ($apps as $app) {
 			if ((is_null($types) or self::isType($app, $types)) && !in_array($app, self::$loadedApps)) {
-				self::$loadedApps[] = $app;
 				self::loadApp($app);
 			}
 		}
@@ -88,6 +87,7 @@ class OC_App {
 	 * @throws \OC\NeedsUpdateException
 	 */
 	public static function loadApp($app, $checkUpgrade = true) {
+		self::$loadedApps[] = $app;
 		if (is_file(self::getAppPath($app) . '/appinfo/app.php')) {
 			if ($checkUpgrade and self::shouldUpgrade($app)) {
 				throw new \OC\NeedsUpdateException();
@@ -288,8 +288,8 @@ class OC_App {
 	 * @return int
 	 */
 	public static function downloadApp($app) {
-		$appData=OC_OCSClient::getApplication($app);
-		$download=OC_OCSClient::getApplicationDownload($app, 1);
+		$appData=OC_OCSClient::getApplication($app, \OC_Util::getVersion());
+		$download=OC_OCSClient::getApplicationDownload($app, 1, \OC_Util::getVersion());
 		if(isset($download['downloadlink']) and $download['downloadlink']!='') {
 			// Replace spaces in download link without encoding entire URL
 			$download['downloadlink'] = str_replace(' ', '%20', $download['downloadlink']);
@@ -928,7 +928,7 @@ class OC_App {
 	 *     Keys: id, name, type, typename, personid, license, detailpage, preview, changed, description
 	 */
 	public static function getAppstoreApps($filter = 'approved') {
-		$categoryNames = OC_OCSClient::getCategories();
+		$categoryNames = OC_OCSClient::getCategories(\OC_Util::getVersion());
 		if (is_array($categoryNames)) {
 			// Check that categories of apps were retrieved correctly
 			if (!$categories = array_keys($categoryNames)) {
@@ -936,7 +936,7 @@ class OC_App {
 			}
 
 			$page = 0;
-			$remoteApps = OC_OCSClient::getApplications($categories, $page, $filter);
+			$remoteApps = OC_OCSClient::getApplications($categories, $page, $filter, \OC_Util::getVersion());
 			$app1 = array();
 			$i = 0;
 			foreach ($remoteApps as $app) {
@@ -1141,7 +1141,7 @@ class OC_App {
 	 */
 	public static function installApp($app) {
 		$l = OC_L10N::get('core');
-		$appData=OC_OCSClient::getApplication($app);
+		$appData=OC_OCSClient::getApplication($app, \OC_Util::getVersion());
 
 		// check if app is a shipped app or not. OCS apps have an integer as id, shipped apps use a string
 		if(!is_numeric($app)) {
@@ -1201,6 +1201,8 @@ class OC_App {
 		$appData = self::getAppInfo($appId);
 		if (array_key_exists('ocsid', $appData)) {
 			OC_Appconfig::setValue($appId, 'ocsid', $appData['ocsid']);
+		} elseif(OC_Appconfig::getValue($appId, 'ocsid', null) !== null) {
+			OC_Appconfig::deleteKey($appId, 'ocsid');
 		}
 		foreach ($appData['remote'] as $name => $path) {
 			OCP\CONFIG::setAppValue('core', 'remote_' . $name, $appId . '/' . $path);
