@@ -1,8 +1,5 @@
 <?php
 
-// Init owncloud
-require_once '../../lib/base.php';
-
 OC_JSON::checkSubAdminUser();
 OCP\JSON::callCheck();
 
@@ -10,13 +7,15 @@ $success = true;
 $username = $_POST["username"];
 $group = $_POST["group"];
 
-if($username == OC_User::getUser() && $group == "admin" &&  OC_Group::inGroup($username, 'admin')){
+if($username === OC_User::getUser() && $group === "admin" &&  OC_User::isAdminUser($username)) {
 	$l = OC_L10N::get('core');
 	OC_JSON::error(array( 'data' => array( 'message' => $l->t('Admins can\'t remove themself from the admin group'))));
 	exit();
 }
 
-if(!OC_Group::inGroup(OC_User::getUser(), 'admin') && (!OC_SubAdmin::isUserAccessible(OC_User::getUser(), $username) || !OC_SubAdmin::isGroupAccessible(OC_User::getUser(), $group))) {
+if(!OC_User::isAdminUser(OC_User::getUser())
+	&& (!OC_SubAdmin::isUserAccessible(OC_User::getUser(), $username)
+		|| !OC_SubAdmin::isGroupAccessible(OC_User::getUser(), $group))) {
 	$l = OC_L10N::get('core');
 	OC_JSON::error(array( 'data' => array( 'message' => $l->t('Authentication error') )));
 	exit();
@@ -34,10 +33,10 @@ $action = "add";
 // Toggle group
 if( OC_Group::inGroup( $username, $group )) {
 	$action = "remove";
-    $error = $l->t("Unable to remove user from group %s", $group);
-    $success = OC_Group::removeFromGroup( $username, $group );
+	$error = $l->t("Unable to remove user from group %s", $group);
+	$success = OC_Group::removeFromGroup( $username, $group );
 	$usersInGroup=OC_Group::usersInGroup($group);
-	if(count($usersInGroup)==0) {
+	if(count($usersInGroup) === 0) {
 		OC_Group::deleteGroup($group);
 	}
 }
