@@ -1,7 +1,7 @@
 <?php
 $TRANSLATIONS = array(
 "Invalid value supplied for %s" => "Type de valeur METADATA invalide : \"%s\".",
-"Saved" => "Sauvegarder",
+"Saved" => "Sauvegardé",
 "test email settings" => "tester les paramètres d'e-mail",
 "If you received this email, the settings seem to be correct." => "Si vous recevez cet email, c'est que les paramètres sont corrects",
 "A problem occurred while sending the e-mail. Please revisit your settings." => "Une erreur est survenue lors de l'envoi de l'e-mail. Veuillez vérifier vos paramètres.",
@@ -37,8 +37,8 @@ $TRANSLATIONS = array(
 "Wrong password" => "Mot de passe incorrect",
 "No user supplied" => "Aucun utilisateur fourni",
 "Please provide an admin recovery password, otherwise all user data will be lost" => "Veuillez fournir un mot de passe administrateur de récupération de données, sinon toutes les données de l'utilisateur seront perdues",
-"Wrong admin recovery password. Please check the password and try again." => "Mot de passe administrateur de récupération de données invalide. Veuillez vérifier le mot de passe et essayer à nouveau.",
-"Back-end doesn't support password change, but the users encryption key was successfully updated." => "L'infrastructure d'arrière-plan ne supporte pas la modification de mot de passe, mais la clef de chiffrement des utilisateurs a été mise à jour avec succès.",
+"Wrong admin recovery password. Please check the password and try again." => "Mot de passe administrateur de récupération de données non valable. Veuillez vérifier le mot de passe et essayer à nouveau.",
+"Back-end doesn't support password change, but the users encryption key was successfully updated." => "L'infrastructure d'arrière-plan ne permet pas la modification de mot de passe, mais la clef de chiffrement des utilisateurs a été mise à jour avec succès.",
 "Unable to change password" => "Impossible de modifier le mot de passe",
 "Sending..." => "Envoi en cours...",
 "User Documentation" => "Documentation utilisateur",
@@ -109,32 +109,32 @@ $TRANSLATIONS = array(
 "Your PHP version is outdated" => "Votre version de PHP est trop ancienne",
 "Your PHP version is outdated. We strongly recommend to update to 5.3.8 or newer because older versions are known to be broken. It is possible that this installation is not working correctly." => "Votre version de PHP est trop ancienne. Nous vous recommandons fortement de migrer vers une version 5.3.8 ou plus récente encore, car les versions antérieures sont réputées problématiques. Il est possible que cette installation ne fonctionne pas correctement.",
 "Locale not working" => "Localisation non fonctionnelle",
-"System locale can not be set to a one which supports UTF-8." => "Les paramètres régionaux ne peuvent pas être configurés avec un qui supporte UTF-8.",
+"System locale can not be set to a one which supports UTF-8." => "Les paramètres régionaux ne peuvent pas être configurés avec prise en charge d'UTF-8.",
 "This means that there might be problems with certain characters in file names." => "Cela signifie qu'il pourrait y avoir des problèmes avec certains caractères dans les noms de fichier.",
 "We strongly suggest to install the required packages on your system to support one of the following locales: %s." => "Nous conseillons vivement d'installer les paquets requis sur votre système pour supporter l'un des paramètres régionaux suivants : %s.",
 "Internet connection not working" => "La connexion internet ne fonctionne pas",
 "This server has no working internet connection. This means that some of the features like mounting of external storage, notifications about updates or installation of 3rd party apps don´t work. Accessing files from remote and sending of notification emails might also not work. We suggest to enable internet connection for this server if you want to have all features." => "Ce serveur ne peut se connecter à internet. Cela signifie que certaines fonctionnalités, telles que le montage de supports de stockage distants, les notifications de mises à jour ou l'installation d'applications tierces ne fonctionneront pas. L'accès aux fichiers à distance, ainsi que les notifications par mails ne seront pas fonctionnels également. Il est recommandé d'activer la connexion internet pour ce serveur si vous souhaitez disposer de l'ensemble des fonctionnalités offertes.",
 "Cron" => "Cron",
-"Last cron was executed at %s." => "Le dernier cron s'est exécuté à %s.",
-"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Le dernier cron s'est exécuté à %s. Cela fait plus d'une heure, quelque chose a du mal se passer.",
+"Last cron was executed at %s." => "Le dernier cron s'est exécuté à la date suivante : %s.",
+"Last cron was executed at %s. This is more than an hour ago, something seems wrong." => "Le dernier cron s'est exécuté à la date suivante : %s. Cela fait plus d'une heure, quelque chose a du mal se passer.",
 "Cron was not executed yet!" => "Le cron n'a pas encore été exécuté !",
 "Execute one task with each page loaded" => "Exécute une tâche à chaque chargement de page",
 "cron.php is registered at a webcron service to call cron.php every 15 minutes over http." => "cron.php est enregistré en tant que service webcron pour appeler cron.php toutes les 15 minutes via http.",
-"Use system's cron service to call the cron.php file every 15 minutes." => "Utilise le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
+"Use system's cron service to call the cron.php file every 15 minutes." => "Utilisez le service cron du système pour appeler le fichier cron.php toutes les 15 minutes.",
 "Sharing" => "Partage",
 "Allow apps to use the Share API" => "Autoriser les applications à utiliser l'API de partage",
-"Allow users to share via link" => "Autoriser les utilisateurs à partager via des liens",
-"Enforce password protection" => "Appliquer la protection par mot de passe",
+"Allow users to share via link" => "Autoriser les utilisateurs à partager par lien",
+"Enforce password protection" => "Obliger la protection par mot de passe",
 "Allow public uploads" => "Autoriser les téléversements publics",
 "Set default expiration date" => "Spécifier la date d'expiration par défaut",
-"Expire after " => "Expire après",
+"Expire after " => "Expiration après ",
 "days" => "jours",
-"Enforce expiration date" => "Impose la date d'expiration",
+"Enforce expiration date" => "Imposer la date d'expiration",
 "Allow resharing" => "Autoriser le repartage",
-"Restrict users to only share with users in their groups" => "Autoriser les utilisateurs à ne partager qu'avec les utilisateurs de leurs groupes",
-"Allow users to send mail notification for shared files" => "Autoriser les utilisateurs à envoyer une notification par courriel concernant les fichiers partagés",
-"Exclude groups from sharing" => "Exclure  les groupes du partage",
-"These groups will still be able to receive shares, but not to initiate them." => "Ces groupes restent autorisés à partager, mais ne peuvent pas les initier",
+"Restrict users to only share with users in their groups" => "N'autoriser les partages qu'entre membres de même groupes",
+"Allow users to send mail notification for shared files" => "Autoriser les utilisateurs à envoyer des notifications par courriel concernant les partages",
+"Exclude groups from sharing" => "Empêcher certains groupes de partager",
+"These groups will still be able to receive shares, but not to initiate them." => "Ces groupes ne pourront plus initier de partage, mais ils pourront toujours rejoindre les partages faits par d'autres. ",
 "Security" => "Sécurité",
 "Enforce HTTPS" => "Forcer HTTPS",
 "Forces the clients to connect to %s via an encrypted connection." => "Forcer les clients à se connecter à %s via une connexion chiffrée.",
@@ -149,7 +149,7 @@ $TRANSLATIONS = array(
 "Credentials" => "Informations d'identification",
 "SMTP Username" => "Nom d'utilisateur SMTP",
 "SMTP Password" => "Mot de passe SMTP",
-"Test email settings" => "Paramètres de test d'e-mail",
+"Test email settings" => "Tester les paramètres e-mail",
 "Send email" => "Envoyer un e-mail",
 "Log" => "Log",
 "Log level" => "Niveau de log",
@@ -183,15 +183,15 @@ $TRANSLATIONS = array(
 "Full Name" => "Nom complet",
 "Email" => "Adresse mail",
 "Your email address" => "Votre adresse e-mail",
-"Fill in an email address to enable password recovery and receive notifications" => "Saisir une adresse e-mail pour permettre la réinitialisation du mot de passe et la réception des notifications",
+"Fill in an email address to enable password recovery and receive notifications" => "Saisissez votre adresse mail pour permettre la réinitialisation du mot de passe et la réception des notifications",
 "Profile picture" => "Photo de profil",
-"Upload new" => "Télécharger nouveau",
-"Select new from Files" => "Sélectionner un nouveau depuis les documents",
+"Upload new" => "Nouvelle depuis votre ordinateur",
+"Select new from Files" => "Nouvelle depuis les Fichiers",
 "Remove image" => "Supprimer l'image",
-"Either png or jpg. Ideally square but you will be able to crop it." => "Soit png ou jpg. Idéalement carrée mais vous pourrez la recadrer.",
+"Either png or jpg. Ideally square but you will be able to crop it." => "Format png ou jpg. Idéalement carrée, mais vous pourrez la recadrer.",
 "Your avatar is provided by your original account." => "Votre avatar est fourni par votre compte original.",
 "Cancel" => "Annuler",
-"Choose as profile image" => "Choisir en temps que photo de profil ",
+"Choose as profile image" => "Choisir en tant que photo de profil ",
 "Language" => "Langue",
 "Help translate" => "Aidez à traduire",
 "The encryption app is no longer enabled, please decrypt all your files" => "L'app de chiffrement n’est plus activée, veuillez déchiffrer tous vos fichiers",
@@ -203,7 +203,7 @@ $TRANSLATIONS = array(
 "Login Name" => "Nom d'utilisateur",
 "Create" => "Créer",
 "Admin Recovery Password" => "Récupération du mot de passe administrateur",
-"Enter the recovery password in order to recover the users files during password change" => "Entrer le mot de passe de récupération dans le but de récupérer les fichiers utilisateurs pendant le changement de mot de passe",
+"Enter the recovery password in order to recover the users files during password change" => "Entrez le mot de passe de récupération pour récupérer les fichiers utilisateurs pendant le changement de mot de passe",
 "Search Users and Groups" => "Chercher parmi les utilisateurs et groupes",
 "Add Group" => "Ajouter un groupe",
 "Group" => "Groupe",
@@ -219,6 +219,8 @@ $TRANSLATIONS = array(
 "Last Login" => "Dernière Connexion",
 "change full name" => "Modifier le nom complet",
 "set new password" => "Changer le mot de passe",
-"Default" => "Défaut"
+"Default" => "Défaut",
+"Connectivity Checks" => "Vérification de la connectivité",
+"No problems found" => "Aucun problème trouvé",
 );
 $PLURAL_FORMS = "nplurals=2; plural=(n > 1);";
