@@ -215,6 +215,8 @@ $TRANSLATIONS = array(
 "Last Login" => "Последний вход",
 "change full name" => "изменить полное имя",
 "set new password" => "установить новый пароль",
-"Default" => "По умолчанию"
+"Default" => "По умолчанию",
+"Connectivity Checks" => "Проверка соединения",
+"No problems found" => "Проблемы не найдены",
 );
 $PLURAL_FORMS = "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2);";
